Overrides — bodhi 3.1.0 documentation

# Overrides

## Override service at /overrides/{nvr}

Buildroot Overrides

### GET

Accepted content types:

- text/html

Return a dictionary with key “override” indexing the override that matches the given nvr.

Args:
  request (pyramid.request): The current request, which should have a query parameter “nvr”,
    providing the nvr of the requested override.
Returns:
  dict: A dictionary with key “override” that indexes the override matching the given nvr.

Response: override.html

### GET

Accepted content types:

- application/javascript

Return a dictionary with key “override” indexing the override that matches the given nvr.

Args:
  request (pyramid.request): The current request, which should have a query parameter “nvr”,
    providing the nvr of the requested override.
Returns:
  dict: A dictionary with key “override” that indexes the override matching the given nvr.

Response: jsonp

### GET

Accepted content types:

- application/json
- text/json

Return a dictionary with key “override” indexing the override that matches the given nvr.

Args:
  request (pyramid.request): The current request, which should have a query parameter “nvr”,
    providing the nvr of the requested override.
Returns:
  dict: A dictionary with key “override” that indexes the override matching the given nvr.

Response: json

## Overrides service at /overrides/

Buildroot Overrides

### GET

values in the querystring

- display_user (Boolean) - (default: true)
- like (String) - (optional)
- search (String) - (optional)
- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- builds (Sequence) - (optional)
- expired (Boolean) - (optional)
- packages (Sequence) - (optional)
- releases (Sequence) - (optional)
- user (String) - (optional)

Accepted content types:

- text/html

Search for overrides by various criteria.

The following optional parameters may be used when searching for overrides:

  builds (list): A list of NVRs to search overrides by. expired (bool): If True, limit search to expired overrides. If False, limit search to active

  > overrides.

  like (basestring): Perform an SQL “like” query against build NVRs with the given string. packages (list): A list of package names to search overrides by. releases (list): A list of release names to limit the overrides search by. search (basestring): Perform an SQL “ilike” query against build NVRs with the given string. submitter (basestring): Search for overrides submitted by the given username.

Returns:
  dict: A dictionary with the following keys:
    overrides: An iterable containing the matched overrides. page: The current page number in the results. pages: The number of pages of results that match the query. rows_per_page: The number of rows on the page. total: The total number of overrides that match the criteria. chrome: The caller supplied chrome. display_user: The current username.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Make sure referenced packages exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced releases exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure the referenced user exists.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: overrides.html

### GET

values in the querystring

- display_user (Boolean) - (default: true)
- like (String) - (optional)
- search (String) - (optional)
- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- builds (Sequence) - (optional)
- expired (Boolean) - (optional)
- packages (Sequence) - (optional)
- releases (Sequence) - (optional)
- user (String) - (optional)

Accepted content types:

- application/javascript

Search for overrides by various criteria.

The following optional parameters may be used when searching for overrides:

  builds (list): A list of NVRs to search overrides by. expired (bool): If True, limit search to expired overrides. If False, limit search to active

  > overrides.

  like (basestring): Perform an SQL “like” query against build NVRs with the given string. packages (list): A list of package names to search overrides by. releases (list): A list of release names to limit the overrides search by. search (basestring): Perform an SQL “ilike” query against build NVRs with the given string. submitter (basestring): Search for overrides submitted by the given username.

Returns:
  dict: A dictionary with the following keys:
    overrides: An iterable containing the matched overrides. page: The current page number in the results. pages: The number of pages of results that match the query. rows_per_page: The number of rows on the page. total: The total number of overrides that match the criteria. chrome: The caller supplied chrome. display_user: The current username.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Make sure referenced packages exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced releases exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure the referenced user exists.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: jsonp

### GET

values in the querystring

- display_user (Boolean) - (default: true)
- like (String) - (optional)
- search (String) - (optional)
- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- builds (Sequence) - (optional)
- expired (Boolean) - (optional)
- packages (Sequence) - (optional)
- releases (Sequence) - (optional)
- user (String) - (optional)

Accepted content types:

- application/json
- text/json

Search for overrides by various criteria.

The following optional parameters may be used when searching for overrides:

  builds (list): A list of NVRs to search overrides by. expired (bool): If True, limit search to expired overrides. If False, limit search to active

  > overrides.

  like (basestring): Perform an SQL “like” query against build NVRs with the given string. packages (list): A list of package names to search overrides by. releases (list): A list of release names to limit the overrides search by. search (basestring): Perform an SQL “ilike” query against build NVRs with the given string. submitter (basestring): Search for overrides submitted by the given username.

Returns:
  dict: A dictionary with the following keys:
    overrides: An iterable containing the matched overrides. page: The current page number in the results. pages: The number of pages of results that match the query. rows_per_page: The number of rows on the page. total: The total number of overrides that match the criteria. chrome: The caller supplied chrome. display_user: The current username.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Make sure referenced packages exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced releases exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure the referenced user exists.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: json

### GET

values in the querystring

- display_user (Boolean) - (default: true)
- like (String) - (optional)
- search (String) - (optional)
- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- builds (Sequence) - (optional)
- expired (Boolean) - (optional)
- packages (Sequence) - (optional)
- releases (Sequence) - (optional)
- user (String) - (optional)

Accepted content types:

- application/atom+xml

Search for overrides by various criteria.

The following optional parameters may be used when searching for overrides:

  builds (list): A list of NVRs to search overrides by. expired (bool): If True, limit search to expired overrides. If False, limit search to active

  > overrides.

  like (basestring): Perform an SQL “like” query against build NVRs with the given string. packages (list): A list of package names to search overrides by. releases (list): A list of release names to limit the overrides search by. search (basestring): Perform an SQL “ilike” query against build NVRs with the given string. submitter (basestring): Search for overrides submitted by the given username.

Returns:
  dict: A dictionary with the following keys:
    overrides: An iterable containing the matched overrides. page: The current page number in the results. pages: The number of pages of results that match the query. rows_per_page: The number of rows on the page. total: The total number of overrides that match the criteria. chrome: The caller supplied chrome. display_user: The current username.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Make sure referenced packages exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced releases exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure the referenced user exists.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: rss

### POST

values in the body

- csrf_token (String)
- nvr (String)
- notes (String)
- expiration_date (DateTime)
- expired (Boolean) - (default: false)
- edited (String) - (optional)

Accepted content types:

- application/javascript

Create or edit a buildroot override.

This entails either creating a new buildroot override, or editing an existing one. To edit an existing buildroot override, the buildroot override’s original id needs to be specified in the `edited` parameter.

Args:
  request (pyramid.request): The current web request.
Returns:
  dict: The new or edited override.

Validate the body against the schema defined on the service.

The content of the body is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Ensure that the override builds are properly referenced.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Ensure the expiration date is in the future.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: jsonp

### POST

values in the body

- csrf_token (String)
- nvr (String)
- notes (String)
- expiration_date (DateTime)
- expired (Boolean) - (default: false)
- edited (String) - (optional)

Accepted content types:

- application/json
- text/json

Create or edit a buildroot override.

This entails either creating a new buildroot override, or editing an existing one. To edit an existing buildroot override, the buildroot override’s original id needs to be specified in the `edited` parameter.

Args:
  request (pyramid.request): The current web request.
Returns:
  dict: The new or edited override.

Validate the body against the schema defined on the service.

The content of the body is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Ensure that the override builds are properly referenced.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Ensure the expiration date is in the future.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: json

## Overrides_Rss service at /rss/overrides/

Buildroot Overrides RSS Feed

### GET

values in the querystring

- display_user (Boolean) - (default: true)
- like (String) - (optional)
- search (String) - (optional)
- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- builds (Sequence) - (optional)
- expired (Boolean) - (optional)
- packages (Sequence) - (optional)
- releases (Sequence) - (optional)
- user (String) - (optional)

Search for overrides by various criteria.

The following optional parameters may be used when searching for overrides:

  builds (list): A list of NVRs to search overrides by. expired (bool): If True, limit search to expired overrides. If False, limit search to active

  > overrides.

  like (basestring): Perform an SQL “like” query against build NVRs with the given string. packages (list): A list of package names to search overrides by. releases (list): A list of release names to limit the overrides search by. search (basestring): Perform an SQL “ilike” query against build NVRs with the given string. submitter (basestring): Search for overrides submitted by the given username.

Returns:
  dict: A dictionary with the following keys:
    overrides: An iterable containing the matched overrides. page: The current page number in the results. pages: The number of pages of results that match the query. rows_per_page: The number of rows on the page. total: The total number of overrides that match the criteria. chrome: The caller supplied chrome. display_user: The current username.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Make sure referenced packages exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced releases exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure the referenced user exists.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: rss